@@ -22,32 +22,35 @@ def test_ad_data():
     data = bytes([2, AdvertisingData.TX_POWER_LEVEL, 123])
     ad = AdvertisingData.from_bytes(data)
     ad_bytes = bytes(ad)
-    assert(data == ad_bytes)
-    assert(ad.get(AdvertisingData.COMPLETE_LOCAL_NAME, raw=True) is None)
-    assert(ad.get(AdvertisingData.TX_POWER_LEVEL, raw=True) == bytes([123]))
-    assert(ad.get(AdvertisingData.COMPLETE_LOCAL_NAME, return_all=True, raw=True) == [])
-    assert(ad.get(AdvertisingData.TX_POWER_LEVEL, return_all=True, raw=True) == [bytes([123])])
+    assert data == ad_bytes
+    assert ad.get(AdvertisingData.COMPLETE_LOCAL_NAME, raw=True) is None
+    assert ad.get(AdvertisingData.TX_POWER_LEVEL, raw=True) == bytes([123])
+    assert ad.get(AdvertisingData.COMPLETE_LOCAL_NAME, return_all=True, raw=True) == []
+    assert ad.get(AdvertisingData.TX_POWER_LEVEL, return_all=True, raw=True) == [
+        bytes([123])
+    ]
 
     data2 = bytes([2, AdvertisingData.TX_POWER_LEVEL, 234])
     ad.append(data2)
     ad_bytes = bytes(ad)
-    assert(ad_bytes == data + data2)
-    assert(ad.get(AdvertisingData.COMPLETE_LOCAL_NAME, raw=True) is None)
-    assert(ad.get(AdvertisingData.TX_POWER_LEVEL, raw=True) == bytes([123]))
-    assert(ad.get(AdvertisingData.COMPLETE_LOCAL_NAME, return_all=True, raw=True) == [])
-    assert(ad.get(AdvertisingData.TX_POWER_LEVEL, return_all=True, raw=True) == [bytes([123]), bytes([234])])
+    assert ad_bytes == data + data2
+    assert ad.get(AdvertisingData.COMPLETE_LOCAL_NAME, raw=True) is None
+    assert ad.get(AdvertisingData.TX_POWER_LEVEL, raw=True) == bytes([123])
+    assert ad.get(AdvertisingData.COMPLETE_LOCAL_NAME, return_all=True, raw=True) == []
+    assert ad.get(AdvertisingData.TX_POWER_LEVEL, return_all=True, raw=True) == [
+        bytes([123]),
+        bytes([234]),
+    ]
 
 
 # -----------------------------------------------------------------------------
 def test_get_dict_key_by_value():
-    dictionary = {
-        "A": 1,
-        "B": 2
-    }
+    dictionary = {"A": 1, "B": 2}
     assert get_dict_key_by_value(dictionary, 1) == "A"
     assert get_dict_key_by_value(dictionary, 2) == "B"
     assert get_dict_key_by_value(dictionary, 3) is None
 
+
 # -----------------------------------------------------------------------------
 if __name__ == '__main__':
-    test_ad_data()
\ No newline at end of file
+    test_ad_data()
