@@ -23,7 +23,9 @@ from bumble.transport import PacketParser
 class ScannerListener(Device.Listener):
     def on_advertisement(self, advertisement):
         address_type_string = ('P', 'R', 'PI', 'RI')[advertisement.address.address_type]
-        print(f'>>> {advertisement.address} [{address_type_string}]: RSSI={advertisement.rssi}, {advertisement.ad_data}')
+        print(
+            f'>>> {advertisement.address} [{address_type_string}]: RSSI={advertisement.rssi}, {advertisement.ad_data}'
+        )
 
 
 class HciSource:
